Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1109)

Unified Diff: content/browser/frame_host/navigation_request.cc

Issue 2484633004: Change Lo-Fi bool to bitmask to support multiple Previews types (Closed)
Patch Set: fix ContentResourceProviderTest Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/frame_host/navigation_request.h ('k') | content/browser/frame_host/navigator_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/navigation_request.cc
diff --git a/content/browser/frame_host/navigation_request.cc b/content/browser/frame_host/navigation_request.cc
index 8a1007d4dd3d6550e05f76faa0f276bcaeedc3b5..964fd95b4cfe42586b8dfe6d23e8b18cbac27e6c 100644
--- a/content/browser/frame_host/navigation_request.cc
+++ b/content/browser/frame_host/navigation_request.cc
@@ -201,7 +201,7 @@ std::unique_ptr<NavigationRequest> NavigationRequest::CreateBrowserInitiated(
const FrameNavigationEntry& frame_entry,
const NavigationEntryImpl& entry,
FrameMsg_Navigate_Type::Value navigation_type,
- LoFiState lofi_state,
+ PreviewsState previews_state,
bool is_same_document_history_load,
bool is_history_navigation_in_new_child,
const base::TimeTicks& navigation_start,
@@ -224,7 +224,7 @@ std::unique_ptr<NavigationRequest> NavigationRequest::CreateBrowserInitiated(
std::unique_ptr<NavigationRequest> navigation_request(new NavigationRequest(
frame_tree_node, entry.ConstructCommonNavigationParams(
frame_entry, request_body, dest_url, dest_referrer,
- navigation_type, lofi_state, navigation_start),
+ navigation_type, previews_state, navigation_start),
BeginNavigationParams(entry.extra_headers(), net::LOAD_NORMAL,
false, // has_user_gestures
false, // skip_service_worker
@@ -490,11 +490,8 @@ void NavigationRequest::OnResponseStarted(
? navigation_handle_->appcache_handle()->appcache_host_id()
: kAppCacheNoHostId;
- // Update the lofi state of the request.
- if (response->head.is_using_lofi)
- common_params_.lofi_state = LOFI_ON;
- else
- common_params_.lofi_state = LOFI_OFF;
+ // Update the previews state of the request.
+ common_params_.previews_state = response->head.previews_state;
// Select an appropriate renderer to commit the navigation.
RenderFrameHostImpl* render_frame_host = nullptr;
« no previous file with comments | « content/browser/frame_host/navigation_request.h ('k') | content/browser/frame_host/navigator_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698